@@ -145,6 +145,10 @@ class NXtree(NXgroup):
                 if shell_names:
                     del _shell[shell_names[0]]
 
+    def node_from_file(self, fname):
+        return [name for name in self.keys() if 
+            os.path.abspath(fname)==os.path.abspath(self[name].nxfilename)][0]
+
 
 class NXTreeItem(QtGui.QStandardItem):
 
@@ -278,9 +282,14 @@ class NXTreeView(QtGui.QTreeView):
     def popMenu(self, node):
         menu = QtGui.QMenu(self)
         menu.addAction(self.plot_data_action)
-        menu.addAction(self.plot_line_action)
-        menu.addAction(self.overplot_data_action)
-        menu.addAction(self.overplot_line_action)
+        try:
+            if ((isinstance(node, NXgroup) and node.nxsignal and node.nxsignal.ndim == 1) or
+                (isinstance(node, NXfield) and node.ndim == 1)):
+                menu.addAction(self.plot_line_action)
+                menu.addAction(self.overplot_data_action)
+                menu.addAction(self.overplot_line_action)
+        except NeXusError:
+            pass
         menu.addSeparator()
         menu.addAction(self.add_action)
         if not isinstance(node, NXroot):
